@@ -15,6 +15,18 @@ from redis.sentinel import Sentinel
 from rediscluster import StrictRedisCluster
 
 
+class Singleton(object):
+    def __init__(self, cls):
+        self._cls = cls
+        self._instance = {}
+
+    def __call__(self, *args, **kwargs):
+        if self._cls not in self._instance:
+            self._instance[self._cls] = self._cls(*args, **kwargs)
+        return self._instance[self._cls]
+
+
+@Singleton
 class RedisDB:
     def __init__(
         self,
@@ -24,6 +36,7 @@ class RedisDB:
         url=None,
         decode_responses=True,
         service_name=None,
+        max_connections=32,
         **kwargs
     ):
         """
@@ -61,23 +74,26 @@ class RedisDB:
                         startup_nodes.append({"host": ip, "port": port})
 
                     if service_name:
-                        log.info("使用redis哨兵模式")
+                        log.debug("使用redis哨兵模式")
                         hosts = [(node["host"], node["port"]) for node in startup_nodes]
-                        sentinel = Sentinel(hosts, socket_timeout=0.5, **kwargs)
+                        sentinel = Sentinel(hosts, socket_timeout=3, **kwargs)
                         self._redis = sentinel.master_for(
                             service_name,
                             password=user_pass,
                             db=db,
                             redis_class=redis.StrictRedis,
+                            decode_responses=decode_responses,
+                            max_connections=max_connections,
                             **kwargs
                         )
 
                     else:
-                        log.info("使用redis集群模式")
+                        log.debug("使用redis集群模式")
                         self._redis = StrictRedisCluster(
                             startup_nodes=startup_nodes,
                             decode_responses=decode_responses,
                             password=user_pass,
+                            max_connections=max_connections,
                             **kwargs
                         )
 
@@ -90,6 +106,7 @@ class RedisDB:
                         db=db,
                         password=user_pass,
                         decode_responses=decode_responses,
+                        max_connections=max_connections,
                         **kwargs
                     )
             else:
@@ -101,9 +118,9 @@ class RedisDB:
             raise
         else:
             if not url:
-                log.info("连接到redis数据库 %s db%s" % (ip_ports, db))
+                log.debug("连接到redis数据库 %s db%s" % (ip_ports, db))
             else:
-                log.info("连接到redis数据库 %s" % (url))
+                log.debug("连接到redis数据库 %s" % (url))
 
         self._ip_ports = ip_ports
         self._db = db
